@@ -13,15 +13,15 @@
 
 Q_LOGGING_CATEGORY(NetstatHelperDebug, "netstat.helper")
 
-NetstatHelper::NetstatHelper()
-{
-}
-
 void NetstatHelper::query()
 {
-    m_executableProcess = new QProcess();
-    m_processKillerTimer = new QTimer();
-    m_processKillerTimer->setSingleShot(true);
+    if (m_executableProcess) {
+        // If we get queried again before the process finished, we'll forcefully terminate the process and start from scratch
+        // without host name resolution to hopefully speed things up.
+        stopProcess();
+    }
+
+    m_executableProcess = new QProcess(this);
 
     /* parameters passed to ss
      *  -r, --resolve       resolve host names
@@ -35,13 +35,8 @@ void NetstatHelper::query()
     const QString executable = QStringLiteral("ss");
 
     connect(m_executableProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &NetstatHelper::stepExecuteFinished);
-
-    connect(m_processKillerTimer, &QTimer::timeout, this, &NetstatHelper::stopProcess);
-
     m_executableProcess->start(executable, netstatArgs, QIODevice::ReadOnly);
 
-    // We wait 10 seconds before killing the process.
-    m_processKillerTimer->start(10000);
     qDebug() << "Running process";
 }
 
@@ -50,10 +45,6 @@ void NetstatHelper::stopProcess()
     qDebug() << "Timing out!";
     m_hasTimeoutError = true;
 
-    m_processKillerTimer->stop();
-    m_processKillerTimer->deleteLater();
-    m_processKillerTimer = nullptr;
-
     m_executableProcess->disconnect();
     m_executableProcess->kill();
     m_executableProcess->deleteLater();
@@ -62,17 +53,6 @@ void NetstatHelper::stopProcess()
 
 void NetstatHelper::stepExecuteFinished(int exitCode)
 {
-    // No need to kill anything - we had success executing the process.
-    if (!m_processKillerTimer) {
-        return;
-    }
-
-    if (m_processKillerTimer != nullptr) {
-        m_processKillerTimer->stop();
-        m_processKillerTimer->deleteLater();
-        m_processKillerTimer = nullptr;
-    }
-
     m_hasError = false;
 
     if (0 != exitCode) {
@@ -81,7 +61,6 @@ void NetstatHelper::stepExecuteFinished(int exitCode)
     } else {
         QList<QStringList> result = parseSSOutput(m_executableProcess->readAllStandardOutput());
         Q_EMIT queryFinished(result);
-        ;
     }
 
     m_executableProcess->deleteLater();
